@@ -12,6 +12,7 @@
 #include "attachmenticonview.h"
 #include "config-enterprise.h"
 #include "ui_attachmenteditdialog.h"
+#include <KFormat>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
 #include <KLocalizedString>
@@ -68,10 +69,16 @@ AttachmentEditDialog::AttachmentEditDialog(AttachmentIconItem *item, QWidget *pa
     } else {
         mUi->mInlineCheck->setEnabled(true);
         mUi->mStackedWidget->setCurrentIndex(1);
-        mUi->mSizeLabel->setText(QStringLiteral("%1 (%2)").arg(KIO::convertSize(item->attachment().size()), QLocale().toString(item->attachment().size())));
+        KFormat format;
+        mUi->mSizeLabel->setText(
+            QStringLiteral("%1 (%2)").arg(format.formatByteSize(item->attachment().size()), QLocale().toString(item->attachment().size())));
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     connect(mUi->mInlineCheck, &QCheckBox::stateChanged, this, &AttachmentEditDialog::inlineChanged);
+#else
+    connect(mUi->mInlineCheck, &QCheckBox::checkStateChanged, this, &AttachmentEditDialog::inlineChanged);
+#endif
     connect(mUi->mURLRequester,
             &KUrlRequester::urlSelected,
             this,
