@@ -63,7 +63,7 @@ public Q_SLOTS:
     void acceptForMe();
     void declineForMe();
 
-private Q_SLOTS:
+private:
     // checks if row is a group,  that can/should be expanded
     void checkIfExpansionIsNeeded(const KCalendarCore::Attendee &attendee);
 
@@ -98,7 +98,6 @@ private Q_SLOTS:
 
     void slotUpdateCryptoPreferences();
 
-private:
     void updateGroupExpand();
 
     void insertAddresses(const KContacts::Addressee::List &list);
@@ -106,7 +105,7 @@ private:
     void changeStatusForMe(KCalendarCore::Attendee::PartStat);
 
     /** Returns if I was the organizer of the loaded event */
-    bool iAmOrganizer() const;
+    [[nodiscard]] bool iAmOrganizer() const;
 
     /** Reads values from a KContacts::Addressee and inserts a new Attendee
      * item into the listview with those items. Used when adding attendees
