@@ -6,6 +6,8 @@
 */
 
 #include "incidencerecurrence.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "incidencedatetime.h"
 #include "ui_dialogdesktop.h"
 
@@ -57,11 +59,14 @@ enum {
 static void setExDateTimesFromExDates(KCalendarCore::Recurrence *r, const KCalendarCore::DateList &exDates)
 {
     KCalendarCore::DateTimeList dts;
-    QDateTime dt = r->startDateTime();
+    const auto incidenceTz = r->startDateTime().timeZone();
+    QDateTime dt = r->startDateTime().toLocalTime();
     dts.reserve(exDates.count());
+    // The exDates are always in local timezone, but the recurrence might be ocurring on a diffrent day
+    // in the incidence original timezone, so make sure to convert the date
     for (const auto &e : exDates) {
         dt.setDate(e);
-        dts.append(dt);
+        dts.append(dt.toTimeZone(incidenceTz));
     }
     r->setExDateTimes(dts);
 }
@@ -72,7 +77,7 @@ IncidenceRecurrence::IncidenceRecurrence(IncidenceDateTime *dateTime, Ui::EventO
     , mMonthlyInitialType(0)
     , mYearlyInitialType(0)
 {
-    setObjectName(QLatin1StringView("IncidenceRecurrence"));
+    setObjectName("IncidenceRecurrence"_L1);
     // Set some sane defaults
     mUi->mRecurrenceTypeCombo->setCurrentIndex(RecurrenceTypeNone);
     mUi->mRecurrenceEndCombo->setCurrentIndex(RecurrenceEndNever);
@@ -111,7 +116,12 @@ IncidenceRecurrence::IncidenceRecurrence(IncidenceDateTime *dateTime, Ui::EventO
     connect(mUi->mRecurrenceEndCombo, &QComboBox::currentIndexChanged, this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mEndDurationEdit, &QSpinBox::valueChanged, this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mRecurrenceEndDate, &KDateComboBox::dateChanged, this, &IncidenceRecurrence::checkDirtyStatus);
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     connect(mUi->mThisAndFutureCheck, &QCheckBox::stateChanged, this, &IncidenceRecurrence::checkDirtyStatus);
+#else
+    connect(mUi->mThisAndFutureCheck, &QCheckBox::checkStateChanged, this, &IncidenceRecurrence::checkDirtyStatus);
+#endif
 }
 
 // this method must be at the top of this file in order to ensure
@@ -405,7 +415,7 @@ bool IncidenceRecurrence::isDirty() const
     } else {
         KCalendarCore::DateList dates;
         for (const auto &dt : recurrence->exDateTimes()) {
-            dates.append(dt.date());
+            dates.append(dt.toLocalTime().date());
         }
         if (mExceptionDates != dates) {
             return true;
@@ -907,8 +917,9 @@ void IncidenceRecurrence::setExceptionDateTimes(const KCalendarCore::DateTimeLis
     mUi->mExceptionList->clear();
     mExceptionDates.clear();
     for (const auto &dt : dateTimes) {
-        mUi->mExceptionList->addItem(QLocale().toString(dt.date()));
-        mExceptionDates.append(dt.date());
+        const auto date = dt.toLocalTime().date();
+        mUi->mExceptionList->addItem(QLocale().toString(date));
+        mExceptionDates.append(date);
     }
 }
 
